#
# spec file for package release-compare
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           release-compare
Summary:        Release Compare Script
License:        GPL-3.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/openSUSE/release-compare
Version:        0.9.1
Release:        1.1
Source:         %name-%version.tar.xz
BuildArch:      noarch
Requires:       python3-PyYAML
Requires:       python3-setuptools
BuildRequires:  python3-PyYAML
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools

%description
This package contains scripts to create changelog files relative
to last released result.

Note: you need to use a releasetarget definition in your OBS repository
      to get this working. And the release target needs to have published binaries.

%prep
%setup -q

%build

%install
make DESTDIR=%{buildroot} PREFIX=%{_prefix}

%check
pytest

%files
%license LICENSE
%doc README.rst
/usr/lib/build

%changelog
* Tue Jun 13 2023 Joachim Gleissner <jgleissner@suse.com>
- 0.9.1
  * Capture package version changes
  * Fix version match regular epxpression
  * Convert (back) to single file script
  * Add runtime dependency on setuptools to spec file
* Fri May 26 2023 Joachim Gleissner <jgleissner@suse.com>
- 0.9.0
  * Re-write of create_changelog in python
  * Support for JSON output
  * Support for handling image config changelog (image history) as
    produced by keg OBS source service (JSON and YAML formats supported)
  * Support for including full package list in change log
  * Parse version number for selecting most recent old obsgendiff
    (avoids mismatches)
  * Add configuration options via _release_compare in package source
* Tue May 17 2022 Joachim Gleissner <jgleissner@suse.com>
- 0.5.6
  * better obsgendiff version string guess
* Tue Apr 27 2021 Joachim Gleissner <jgleissner@suse.com>
- 0.5.5
  * Use package versions for change log (yaml) generation
* Mon Feb  8 2021 Joachim Gleissner <jgleissner@suse.com>
- 0.5.4
  * fix CVE regex
* Wed Feb  3 2021 Adrian Schröter <adrian@suse.de>
- 0.5.3
  * fix regex for CVE scan
  * fix glob for old obsgendiff file name expansion
* Tue Feb  2 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.5.2
  * escape backslashes in YAML string
* Mon Feb  1 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.5.1
  * Handle packages info without license tag correctly
  * fix potential diff format issue
* Wed Dec 16 2020 Joachim Gleissner <jgleissner@suse.com>
- create list of package version changes in YAML output
* Thu Dec 10 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.5.0
  * exports changes also as YAML file (provided by Joachim Gleissner)
* Tue Nov 10 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.4.1
  * support short rpm structures for appliance server side builds
* Mon Sep 28 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.4.0
  * requires new build script!
  * move script into obsgendiff.d directory
  * minor output improvement
* Fri Sep 25 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.15
  * allow to run further plugins by providing executables
    in /usr/lib/build/obsgendiff.d
    NOTE: we may move this functionality into build script
* Fri Sep 25 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.14
  * Pick newest obsgendiff archive if multiple exists
    in maintenance_release projects
* Wed Sep 23 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.13
  * strip package name containers from incident projects
  * drop wrong and needless stripping of package names
* Thu Sep 17 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.12
  * get right package container name from disturl
* Wed Sep 16 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.11
  * relax report parsing
    (either single or double quotes might be used depending on
    the build stage)
  * hide author (and email) lines in diff
* Tue Sep 15 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.10
  * fixed escaping in sed statement
* Mon Sep 14 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.9
  * fix one more subtile difference in kiwi appliance builds
* Mon Sep 14 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.8
  * fix parsing of kiwi appliance packages files
* Mon Sep 14 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.7
  * update for missing Build numbers in media
    (eg openSUSE ftp tree builds)
* Fri Sep 11 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.6
  * fix touching used rpms
* Thu Sep 10 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.5
  * List added/removed rpm binary names, but diff changes
    via src rpm names
  * syntax fix
* Wed Sep  9 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.4
  * avoid double Changelog txt suffix
  * guess file names need to work with -Snapshot file names on factory
  * work on source rpm name base only
  * strip "first" lines of changes to hide the email adresses
* Wed Sep  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.3
  * beautify diff of import packages
* Wed Sep  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.2
  * handling changed version of a medium
* Tue Sep  1 2020 Adrian Schröter <adrian@suse.de>
- update to version 0.3.1
  * added support for Dockerfile builds
- use git repo as resource
* Mon Aug 31 2020 Adrian Schröter <adrian@suse.de>
- support also plain kiwi builds
* Wed Aug 26 2020 Adrian Schröter <adrian@suse.de>
- write changelogs in UTF-8 encoding
* Tue Aug 25 2020 Adrian Schröter <adrian@suse.de>
- speedup it a lot to avoid timeout errors
* Wed Aug 19 2020 Adrian Schröter <adrian@suse.de>
- running based on .report instead of .packages files
* Mon Feb  3 2020 Adrian Schröter <adrian@suse.de>
- initial demo package
